use anyhow::Result;
use dbus::blocking::Connection;

use bluetooth::BluetoothInfo;
use user_info::UserInfo;

mod bluetooth;
mod user_info;

#[derive(serde::Serialize)]
struct SystemInfo {
    bluetooth: Vec<BluetoothInfo>,
    user: UserInfo
}

fn main() -> Result<()> {
    let connection = Connection::new_system()?;
    let bluetooth = bluetooth::get_all_bluetooth_devices(&connection);
    let user = UserInfo::new(&connection).unwrap_or_default();
    let info = SystemInfo { bluetooth, user };
    println!("{}", serde_json::to_string(&info)?);
    Ok(())
}
